OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalendar",
    "Todos" : "Për tu bërë",
    "Personal" : "Personale",
    "{actor} created calendar {calendar}" : "{aktori} krijoi kalendarin {kalendarin}",
    "You created calendar {calendar}" : "Ju krijuat kalendarin {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} fshiu kalendarin {calendar}",
    "You deleted calendar {calendar}" : "Ju fshit kalendarin {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} përditësoi kalendarin {calendar}",
    "You updated calendar {calendar}" : "Ju përditësuat kalendarin {calendar}",
    "{actor} shared calendar {calendar} with you" : " {actor} ndau kalendarin {calendar} me ju",
    "You shared calendar {calendar} with {user}" : "Ju ndat kalendarin {calendar} me {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} ndau kalendarin {calendar} me {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} ndaloj së ndari kalendarin {calendar} me ju",
    "You unshared calendar {calendar} from {user}" : "Ju ndaluat së ndari kalendarin {calendar} me {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} ndaloj së ndari kalendarin {calendar} me {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} ndaloj së ndari kalendarin {calendar} me veten",
    "You shared calendar {calendar} with group {group}" : "Ju ndat kalendarin {calendar} me grupin {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} ndau kalendarin {calendar} me grupin {group}",
    "You unshared calendar {calendar} from group {group}" : "Ju ndaluat së ndari kalendarin {calendar} me grupin {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} ndaloj së ndari kalendarin {calendar} me grupin {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} krijoj eventin {event} në kalendarin {calendar}",
    "You created event {event} in calendar {calendar}" : "Ju krijuat eventin {event} në kalendarin {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} fshiu eventin {event} nga kalendari {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Ju fshit eventin {event} nga kalndari {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} përditsoi eventin {event} në kalndarin {calendar}",
    "You updated event {event} in calendar {calendar}" : "Ju përditësuat eventin {event} në kalndarin {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} u krijua todo{todo} në listën {calendar}",
    "You created todo {todo} in list {calendar}" : "Ju krijuat todo {todo} në listën {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} u fshi todo{ todo} nga lista{calendar}",
    "You deleted todo {todo} from list {calendar}" : "Ju fshit todo{todo} nga lista {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} u përditësua todo{todo} në listën{calendar}",
    "You updated todo {todo} in list {calendar}" : "Ju përditësuat përtëbërë {todo} në listën{calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} zgjidhi përtëbërë {todo} në listën {calendar}",
    "You solved todo {todo} in list {calendar}" : "Ju zgjidhët përtëbërë {todo} në listën {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} rihapi përtëbërë {todo} në listën {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Ju rihapët përtëbërë {todo} në listën {calendar}",
    "A <strong>calendar</strong> was modified" : "Një <strong>kalendar</strong> u modifikua",
    "A calendar <strong>event</strong> was modified" : "Një <strong>event</strong> në kalendar u modifikua",
    "A calendar <strong>todo</strong> was modified" : "Një kalendar <strong>todo<strong> u modifikua",
    "Contact birthdays" : "Ditëlindjet e kontakteve",
    "Where:" : "Ku:",
    "Description:" : "Përshkrimi:",
    "Invitation canceled" : "Ftesa u anullua",
    "Hello %s," : "Përshëndetje %s,",
    "Invitation updated" : "Ftesa u përditësua",
    "When:" : "Kur:",
    "Link:" : "Link:",
    "Accept" : "Prano",
    "Decline" : "Refuzo",
    "More options …" : "Më shumë opsione ...",
    "Contacts" : "Kontaktet",
    "WebDAV" : "WebDAV",
    "Technical details" : "Detaje teknike",
    "Remote Address: %s" : "Adresa remote: %s",
    "Request ID: %s" : "ID e kërkesës: %s",
    "Tentative" : "Tentativë",
    "Save" : "Ruaj",
    "Your attendance was updated successfully." : "Pjesëmarrja juaj u përditësua me sukses.",
    "Send invitations to attendees" : "Dërgo ftesa tek pjesëmarrësit"
},
"nplurals=2; plural=(n != 1);");
